"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var MfCompositionType = _interopRequireWildcard(require("../enums/MfCompositionType"));
var _IMembershipFunction = _interopRequireDefault(require("./IMembershipFunction"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/**
 * Composition of several membership functions represened as single membership function
 */
class _default extends _IMembershipFunction.default {
  /**
   * Constructor
   * @param {MfCompositionType} composType Membership functions composition type
   * @param {Array} [mfs] Membership functions
   */
  constructor(composType, mfs) {
    super();
    this._composType = composType;
    this._mfs = mfs || [];
  }

  /**
   * @returns {Array} List of membership functions
   */
  get membershipFunction() {
    return this._mfs;
  }

  /**
   * @returns {MfCompositionType} Membership functions composition type
   */
  get compositionType() {
    return this._composType;
  }

  /**
   * Membership functions composition type
   * @param {MfCompositionType} val
   */
  set compositionType(val) {
    this._composType = val;
  }

  /**
   * Evaluate value of the membership function
   * @param {number} x Argument (x axis value)
   * @returns {number}
   */
  getValue(x) {
    var mfsLength = this._mfs.length;
    if (mfsLength === 0) {
      return 0.0;
    }
    if (mfsLength === 1) {
      return this._mfs[0].getValue(x);
    }
    var result = this._mfs[0].getValue(x);
    for (var i = 1; i < mfsLength; i++) {
      result = this.compose(result, this._mfs[i].getValue(x));
    }
    return result;
  }

  /**
   *
   * @param {number} val1
   * @param {number} val2
   * @returns {number}
   */
  compose(val1, val2) {
    switch (this._composType) {
      case MfCompositionType.Max:
        return Math.max(val1, val2);
      case MfCompositionType.Min:
        return Math.min(val1, val2);
      case MfCompositionType.Prod:
        return val1 * val2;
      case MfCompositionType.Sum:
        return val1 + val2;
      default:
        throw new Error('Internal exception');
    }
  }
}
exports.default = _default;