"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _NamedVariable = _interopRequireDefault(require("./NamedVariable"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * Linguistic variable
 */
class _default extends _NamedVariable.default {
  /**
   * Constructor
   * @param {string} name Name of the variable
   * @param {number} min Minimum value
   * @param {number} max Maximum value
   */
  constructor(name, min, max) {
    super(name);
    if (min > max) {
      throw new Error('Maximum value must be greater than minimum one.');
    }
    this._min = min;
    this._max = max;
    this._terms = [];
  }

  /**
   * @returns {FuzzyTerm[]} Terms
   */
  get terms() {
    return this._terms;
  }

  /**
   * @returns {NamedValue[]} Named values
   */
  get values() {
    return this._terms;
  }

  /**
   * Get membership function (term) by name
   * @param {string} name Term name
   * @returns {FuzzyTerm}
   */
  getTermByName(name) {
    for (var term of this._terms) {
      if (term.name === name) {
        return term;
      }
    }
    throw new Error('Key not found');
  }

  /**
   * @returns {number} Maximum value of the variable
   */
  get max() {
    return this._max;
  }

  /**
   * Set maximum value of the variable
   * @param {number} val
   */
  set max(val) {
    this._max = val;
  }

  /**
   * @returns {number} Minimum value of the variable
   */
  get min() {
    return this._min;
  }

  /**
   * Set minimum value of the variable
   * @param {number} val
   */
  set min(val) {
    this._min = val;
  }
}
exports.default = _default;