"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _NamedVariable = _interopRequireDefault(require("./NamedVariable"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * Used as an output variable in Sugeno fuzzy inference system.
 */
class _default extends _NamedVariable.default {
  /**
   * Constructor
   * @param {string} name Name of the variable
   */
  constructor(name) {
    super(name);
    this._functions = [];
  }

  /**
   * @returns {SugenoFunction[]} List of functions that belongs to the variable
   */
  get functions() {
    return this._functions;
  }

  /**
   * @returns {NamedValue[]} List of functions that belongs to the variable (implementation of INamedVariable)
   */
  get values() {
    return this._functions;
  }

  /**
   * Find function by its name
   * @param {string} name Name of the function
   * @returns {SugenoFunction} Found function
   */
  getFuncByName(name) {
    for (var func of this._functions) {
      if (func.name === name) {
        return func;
      }
    }
    throw new Error('Key not found');
  }
}
exports.default = _default;